/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.bundle;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class CascadingBundleFactory implements BundleFactory {
  BundleFactory masterFactory;

  /** {@inheritDoc} */
  public CascadingBundleFactory(BundleFactory aMasterFactory) {
    masterFactory = aMasterFactory;
  }

  /** {@inheritDoc} */
  public Bundle getBundle(final String aDirectory, final String[] aParameters) {
    return
      new Bundle() {
        public String getValue(String aKey, List anArguments) {
          String result = masterFactory.getBundle(aDirectory, aParameters).getValue(aKey, anArguments);

          if (aParameters.length>0 && result==null) {
            List parameters = new ArrayList(Arrays.asList(aParameters));

            while (result==null && parameters.size()>0) {
              parameters.remove(parameters.size()-1);
              result = masterFactory.getBundle(
                  aDirectory, (String[]) parameters.toArray(new String[0])).getValue(aKey, anArguments);
            }
          }

          return result;
        }
      };
  }

  /** {@inheritDoc} */
  public void reload() {
    masterFactory.reload();
  }
}
