/*
 * Copyright (C) 2001, 2002 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License,
 * The Sun (tm) Java Advanced Imaging library (JAI), The Sun JIMI library
 * (or with modified versions of the above that use the same license as the above),
 * and distribute linked combinations including the two.  You must obey the
 * GNU General Public License in all respects for all of the code used other than
 * the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mircoders.localizer.basic.actions;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import mir.entity.adapter.EntityAdapter;
import mircoders.localizer.MirLocalizerExc;
import mircoders.localizer.MirLocalizerFailure;
import mircoders.localizer.basic.MirBasicAdminInterfaceLocalizer;
import mircoders.storage.DatabaseContentToTopics;

public class ArticleTopicAction implements MirBasicAdminInterfaceLocalizer.EntityOperation {
  private String name;
  private List deleteTopics;
  private List addTopics;

  public ArticleTopicAction(String aName, int[] aDeleteTopics, int[] anAddTopics) {
    name = aName;
    deleteTopics = new ArrayList();
    for (int i=0; i< aDeleteTopics.length; i++) {
      deleteTopics.add(Integer.toString(aDeleteTopics[i]));
    }
    addTopics = new ArrayList();
    for (int i=0; i< anAddTopics.length; i++) {
      addTopics.add(Integer.toString(anAddTopics[i]));
    }
  }

  public String getName() {
    return name;
  }

  public boolean isAvailable(EntityAdapter anEntity) throws MirLocalizerExc, MirLocalizerFailure {
    return true;
  }

  public void perform(EntityAdapter aUser, EntityAdapter anEntity) throws MirLocalizerExc, MirLocalizerFailure {
    DatabaseContentToTopics db = DatabaseContentToTopics.getInstance();

    List topicsToSet = new ArrayList(db.getTopicsOfContent(anEntity.getEntity().getId()));

    topicsToSet.removeAll(deleteTopics);
    topicsToSet.addAll(addTopics);

    db.setTopics(anEntity.getEntity().getId(), topicsToSet);
  }

  public void perform2(EntityAdapter aUser, EntityAdapter anEntity) throws MirLocalizerExc, MirLocalizerFailure {
    DatabaseContentToTopics db = DatabaseContentToTopics.getInstance();

    List integerTopicsToSet = new ArrayList(db.getTopicsOfContent(anEntity.getEntity().getId()));
    List topicsToSet = new ArrayList();
    Iterator i = integerTopicsToSet.iterator();
    while (i.hasNext()) {
      topicsToSet.add(i.next().toString());
    }

    topicsToSet.removeAll(deleteTopics);
    topicsToSet.addAll(addTopics);

    db.setTopics(anEntity.getEntity().getId(), topicsToSet);
  }
}
